A dataset with data on hospital acquired Clostridium difficile infections (CDI) before and after an intervention to reduce the risk of CDI.
A dataset with data on hospital acquired Clostridium difficile infections (CDI) before and after an intervention to reduce the risk of CDI.